==> qtjambi-xml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiXml/QXmlContentHandler_shell.h <==
#ifndef QXMLCONTENTHANDLER_IMPL_SHELL_H
#define QXMLCONTENTHANDLER_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtXml/qxml.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QXmlContentHandler_shell : public QXmlContentHandler, public QtJambiShellInterface
{
public:
    QXmlContentHandler_shell();
    ~QXmlContentHandler_shell() override;

    bool characters(const QString& ch0) override;
    bool endDocument() override;
    bool endElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2) override;
    bool endPrefixMapping(const QString& prefix0) override;
    QString errorString() const override;
    bool ignorableWhitespace(const QString& ch0) override;
    bool processingInstruction(const QString& target0, const QString& data1) override;
    void setDocumentLocator(QXmlLocator* locator0) override;
    bool skippedEntity(const QString& name0) override;
    bool startDocument() override;
    bool startElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2, const QXmlAttributes& atts3) override;
    bool startPrefixMapping(const QString& prefix0, const QString& uri1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXmlContentHandler_access : public QXmlContentHandler
{
    jboolean __qt_characters_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_endDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endElement_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2);
    jboolean __qt_endPrefixMapping_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0);
    jstring __qt_errorString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_ignorableWhitespace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_processingInstruction_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring target0, jstring data1);
    void __qt_setDocumentLocator_QXmlLocator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locator0);
    jboolean __qt_skippedEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startElement_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2, QtJambiNativeID atts3);
    jboolean __qt_startPrefixMapping_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0, jstring uri1);
};

#endif // QXMLCONTENTHANDLER_IMPL_SHELL_H

==> qtjambi-xml-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiXml/QXmlContentHandler_shell.h <==
#ifndef QXMLCONTENTHANDLER_IMPL_SHELL_H
#define QXMLCONTENTHANDLER_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtXml/qxml.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QXmlContentHandler_shell : public QXmlContentHandler, public QtJambiShellInterface
{
public:
    QXmlContentHandler_shell();
    ~QXmlContentHandler_shell() override;

    bool characters(const QString& ch0) override;
    bool endDocument() override;
    bool endElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2) override;
    bool endPrefixMapping(const QString& prefix0) override;
    QString errorString() const override;
    bool ignorableWhitespace(const QString& ch0) override;
    bool processingInstruction(const QString& target0, const QString& data1) override;
    void setDocumentLocator(QXmlLocator* locator0) override;
    bool skippedEntity(const QString& name0) override;
    bool startDocument() override;
    bool startElement(const QString& namespaceURI0, const QString& localName1, const QString& qName2, const QXmlAttributes& atts3) override;
    bool startPrefixMapping(const QString& prefix0, const QString& uri1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXmlContentHandler_access : public QXmlContentHandler
{
    jboolean __qt_characters_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_endDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_endElement_cref_QString_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2);
    jboolean __qt_endPrefixMapping_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0);
    jstring __qt_errorString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_ignorableWhitespace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring ch0);
    jboolean __qt_processingInstruction_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring target0, jstring data1);
    void __qt_setDocumentLocator_QXmlLocator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locator0);
    jboolean __qt_skippedEntity_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jboolean __qt_startDocument(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_startElement_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring namespaceURI0, jstring localName1, jstring qName2, QtJambiNativeID atts3);
    jboolean __qt_startPrefixMapping_cref_QString_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring prefix0, jstring uri1);
};

#endif // QXMLCONTENTHANDLER_IMPL_SHELL_H
